@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 2000-2003, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 2000-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -13,6 +13,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <float.h>
+#include <string.h>
 #include <gdk/gdk.h>
 
 #include "xnecview.h"
@@ -44,7 +45,10 @@ void fixrange1(double *mi, double *ma, int *np)
    double newmin,newmax;
    int i;
    int n=*np;
+/*
    static double acceptable[]={10, 5.0, 2.5, 2.0, 1.0, -1};
+*/
+   static double acceptable[]={10, 5.0, 2.0, 1.0, -1};
 
    if (*ma==*mi) {
       if (*mi>0) {*mi=0; *ma=2* *ma;}
@@ -218,12 +222,9 @@ void freqplot(
    if (min2>max2) { idx2=-1; idx2a=-1; }
 
    /* extend the ranges to have 'round' numbers at each division */
-   ntx=win2sizex/40;
+   ntx=(xright-xleft)/fontheight/3;
    fixrange1(&minf,&maxf,&ntx);
-   nty=10;
-   if (ybot-ytop<10*fontheight) nty=5;
-   if (ybot-ytop<5*fontheight) nty=2;
-   if (ybot-ytop<2*fontheight) nty=1;
+   nty = (ybot-ytop)/fontheight;
    if (idx1>=0) {
       if (idx1==neco_zr) {
          if (max1 > 20*r0) max1 = 20*r0;
@@ -266,9 +267,15 @@ void freqplot(
          SetForeground(&c_scale);
          DrawLine(x,ybot,x,ytop);
       }
-      sprintf(s,"%g",f);
       SetForeground(&c_axis);
+      sprintf(s,"%g",f);
       DrawString(x,ybot+1,s,0.5,1);
+      if (i==ntx) {
+         int l;
+         l=strlen(s);
+         sprintf(s,"                MHz"+(15-(l+1)/2));
+         DrawString(x,ybot+1,s,0,1);
+      }
    }
    if (idx1<0) { min1=1; max1=2; }
    /* horizontal grid lines and associated labels */
@@ -311,11 +318,11 @@ void freqplot(
    }
    if (title1) {
       SetForeground(color1);
-      DrawString(xleft, ytop-1, title1, 0.5,0);
+      DrawString(xleft-fontheight, ytop-1, title1, 0,0);
    }
    if (title2) {
       SetForeground(color2);
-      DrawString(xright, ytop-1, title2, 0.5,0);
+      DrawString(xright+fontheight, ytop-1, title2, 1,0);
    }
 
    /* the actual data points and connecting lines */
@@ -424,11 +431,11 @@ void draw_all2(int onlyvgain)
 
    if (!onlyvgain) ClearWindow();
    if (plot2_z2) {
-      if (!onlyvgain) freqplot(neco_zphi,neco_zabs,-1,-1,"phi(Z)","|Z|","impedance",&c_exci,&c_load,y,y-size);
+      if (!onlyvgain) freqplot(neco_zphi,neco_zabs,-1,-1,"phi(Z) [deg]","[ohm] |Z|","impedance",&c_exci,&c_load,y,y-size);
       y-=step;
    }
    if (plot2_z) {
-      if (!onlyvgain) freqplot(neco_zr,neco_zi,-1,-1,"real","imag","impedance",&c_exci,&c_load,y,y-size);
+      if (!onlyvgain) freqplot(neco_zr,neco_zi,-1,-1,"real [ohm]","[ohm] imag","impedance",&c_exci,&c_load,y,y-size);
       y-=step;
    }
    if (plot2_swr) {
@@ -437,7 +444,7 @@ void draw_all2(int onlyvgain)
    }
    if (plot2_dir) {
       if (!onlyvgain) {
-         if (polarization==POLnone || polarization==POLcolour) freqplot(neco_phi,neco_theta,-1,-1,"phi","theta","direction of maximum gain",&c_exci,&c_load,y,y-size);
+         if (polarization==POLnone || polarization==POLcolour) freqplot(neco_phi,neco_theta,-1,-1,"phi [deg]","[deg] theta","direction of maximum gain",&c_exci,&c_load,y,y-size);
          else freqplot(Neco_polphi+Neco_gsize*polarization,
                        Neco_poltheta+Neco_gsize*polarization,
                        neco_phi,neco_theta,"phi","theta","direction of maximum gain",&c_exci,&c_load,y,y-size);
@@ -446,7 +453,7 @@ void draw_all2(int onlyvgain)
    }
    if (plot2_maxgain) {
       if (!onlyvgain) {
-         if (polarization==POLnone || polarization==POLcolour) freqplot(neco_maxgain,neco_fb,-1,-1,"gain","f/b","in direction of maximum gain",&c_gain,&c_surf,y,y-size);
+         if (polarization==POLnone || polarization==POLcolour) freqplot(neco_maxgain,neco_fb,-1,-1,"gain [dB]","[dB] f/b","in direction of maximum gain",&c_gain,&c_surf,y,y-size);
          else freqplot(Neco_polgain+Neco_gsize*polarization,
                        Neco_polfb1+Neco_gsize*polarization,
                        neco_maxgain,
@@ -457,8 +464,8 @@ void draw_all2(int onlyvgain)
    }
    if (plot2_vgain) {
       if (onlyvgain) ClearRectangle(0,(y-size)*win2sizey,win2sizex,y*win2sizey);
-      if (polarization==POLnone || polarization==POLcolour) freqplot(neco_vgain,neco_vfb,-1,-1,"gain","f/b","in direction toward viewer",&c_gain,&c_surf,y,y-size);
-      else freqplot(neco_vgain2,neco_vfb,neco_vgain,neco_vfb2,"gain","f/b","in direction toward viewer",&c_gain,&c_surf,y,y-size);
+      if (polarization==POLnone || polarization==POLcolour) freqplot(neco_vgain,neco_vfb,-1,-1,"gain [dB]","[dB] f/b","in direction toward viewer",&c_gain,&c_surf,y,y-size);
+      else freqplot(neco_vgain2,neco_vfb,neco_vgain,neco_vfb2,"gain [dB]","[dB] f/b","in direction toward viewer",&c_gain,&c_surf,y,y-size);
       y-=step;
    }
    out->Complete();
