@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2002, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -30,9 +30,7 @@
 
 
 int nextabs;        /* next absolute segment number to be assigned */
-
-
-
+char lastCard[2];   /* type of previous card */
 
 double len3d(Point p1)    /* calculates length of 3D vector p1 */
 {
@@ -60,8 +58,6 @@ void out3d(Surface *su,double f)  /* calculates su->pa, with f determining the l
 }
 
 
-
-
 void updateextremes(Point *p)
 {
    if (p->x>extr_str) extr_str=p->x;
@@ -528,20 +524,84 @@ int read_nec_GX(char *s)     /* GX -> reflection in coordinate planes */
    return 0;
 }
 
-int read_nec_SC(char *s)     /* SC -> continuation of SM */
+int read_nec_SC(char *s)     /* SC -> continuation of SM, SP, or SC */
 {
    Surface *su;
+   int ns;
    Point p3;
+   int n;
+
+   if(lastCard[0]!='S'){ fprintf(stderr,"SC card not preceded by SM, SP, or SC.\n"); return Err_misc; }
+
    EXPAND_IF_NECESSARY(numsurfaces,maxsurfaces,surfaces)
    su=surfaces+numsurfaces++;
    removecommas(s);
-   if (sscanf(s,"SC%*i%*i%g%g%g",&su->p2.x,&su->p2.y,&su->p2.z) != 3) return Err_scan;
-   updateextremes(&su->p2);
-   su->pc=int3d(su->p0,su->p2,0.5);
-   p3=int3d(su->p1,su->pc,2);
-   updateextremes(&p3);
-   out3d(su,0.05);
-   su->type=SU_rect;
+
+   switch (lastCard[1]) {
+      case 'M':
+         if (sscanf(s,"SC%*i%*i%g%g%g",&su->p2.x,&su->p2.y,&su->p2.z) != 3) return Err_scan;
+         updateextremes(&su->p2);
+         su->pc=int3d(su->p0,su->p2,0.5);
+         p3=int3d(su->p1,su->pc,2);
+         updateextremes(&p3);
+         out3d(su,0.05);
+         su->type=SU_rect;
+         break;
+      case 'P':
+         n=sscanf(s,"SC%*i%*i%g%g%g%g%g%g",&su->p2.x,&su->p2.y,&su->p2.z,&su->p3.x,&su->p3.y,&su->p3.z);
+         if (n!=6 && n!=3) return Err_scan;
+         updateextremes(&su->p2);
+         switch (su->type) {
+            case SU_rect:
+               su->pc=int3d(su->p0,su->p2,0.5);
+               su->p3=int3d(su->p1,su->pc,2);    // we don't really need su->p3 now, but do need it in case of continuation using more SC cards
+               updateextremes(&su->p3);
+               out3d(su,0.05);
+               break;
+            case SU_tri:
+               su->pc=int3d(int3d(su->p0,su->p1,0.5),su->p2,1./3);
+               out3d(su,0.05);
+               break;
+            case SU_quad:
+               if (n!=6) return Err_scan;
+               updateextremes(&su->p3);
+               su->pc=int3d(int3d(su->p0,su->p1,0.5),int3d(su->p2,su->p3,0.5),0.5);
+               out3d(su,0.05);
+               break;
+            default:
+               fprintf(stderr,"SC card for surface type which is not rectangle/triangle/quadrilateral.\n"); return Err_misc; 
+         }
+         break;
+      case 'C':
+         n=sscanf(s,"SC%*i%d%g%g%g%g%g%g",&ns,&su->p2.x,&su->p2.y,&su->p2.z,&su->p3.x,&su->p3.y,&su->p3.z);
+         if (n!=7 && n!=4) return Err_scan;
+         Surface *suLast=surfaces+(numsurfaces-2);
+         su->p0=suLast->p3;
+         su->p1=suLast->p2;
+         updateextremes(&su->p2);
+         switch (ns) {
+            case 1:
+               su->type=SU_rect;
+               su->pc=int3d(su->p0,su->p2,0.5);
+               su->p3=int3d(su->p1,su->pc,2);
+               updateextremes(&su->p3);
+               out3d(su,0.05);
+               break;
+            case 3:
+               if (n!=7) return Err_scan;
+               su->type=SU_quad;
+               updateextremes(&su->p3);
+               su->pc=int3d(int3d(su->p0,su->p1,0.5),int3d(su->p2,su->p3,0.5),0.5);
+               out3d(su,0.05);
+               break;
+            default:
+               fprintf(stderr,"SC card specifying unsupported shape NS=%d.\n",ns); return Err_misc; 
+         }
+         break;
+      default:
+         fprintf(stderr,"SC card following card %c%c.\n",lastCard[0],lastCard[1]); return Err_misc; 
+   }
+
    return 0;
 }
 
@@ -565,24 +625,46 @@ int read_nec_SP(char *s)     /* SP -> surface patch */
    double r;
 
    EXPAND_IF_NECESSARY(numsurfaces,maxsurfaces,surfaces)
-   su=surfaces+numsurfaces++;
+   su=surfaces+numsurfaces;  
    su->type=SU_arb;
    removecommas(s);
    if (sscanf(s,"SP%*d%d%lg%lg%lg%lg%lg%lg",&ns,&x1,&y1,&z1,&x2,&y2,&z2) !=7) return Err_scan;
-   if (ns!=0) { fprintf(stderr,"Only \"arbitrary\" patch shape (NS=0) supported for now.\n"); return Err_misc; }
-   su->pc.x=x1; su->pc.y=y1; su->pc.z=z1;
-   updateextremes(&su->pc);
-   r=sqrt(z2/M_PI);
-   x2*=M_PI/180; y2*=M_PI/180;
-   su->p0.x = x1 - r*sin(y2);
-   su->p0.y = y1 + r*cos(y2);
-   su->p0.z = z1;
-   su->p1.x = x1 - r*sin(x2)*cos(y2);
-   su->p1.y = y1 - r*sin(x2)*sin(y2);
-   su->p1.z = z1 + r*cos(x2);
-   su->p2=int3d(su->p0,su->pc,2);
-   out3d(su,0.1);
 
+   if (ns==0) {
+      su->type=SU_arb;
+      su->pc.x=x1; su->pc.y=y1; su->pc.z=z1;
+      updateextremes(&su->pc);
+      r=sqrt(z2/M_PI);
+      x2*=M_PI/180; y2*=M_PI/180;
+      su->p0.x = x1 - r*sin(y2);
+      su->p0.y = y1 + r*cos(y2);
+      su->p0.z = z1;
+      su->p1.x = x1 - r*sin(x2)*cos(y2);
+      su->p1.y = y1 - r*sin(x2)*sin(y2);
+      su->p1.z = z1 + r*cos(x2);
+      su->p2=int3d(su->p0,su->pc,2);
+      out3d(su,0.1);
+      ++numsurfaces;
+      return 0;      
+   }
+
+   switch (ns) {
+      case 1:
+         su->type=SU_rect;
+         break;
+      case 2:
+         su->type=SU_tri;
+         break;
+      case 3:
+         su->type=SU_quad;
+         break;
+      default:
+         fprintf(stderr,"Unknown patch shape: NS=%i.\n",ns); return Err_misc;
+   }
+   su->p0.x=x1; su->p0.y=y1; su->p0.z=z1;
+   su->p1.x=x2; su->p1.y=y2; su->p1.z=z2;
+   updateextremes(&su->p0);
+   updateextremes(&su->p1);
    return 0;
 }
 
@@ -661,6 +743,8 @@ void read_nec_input(FILE *f)               /* read the input file, and update th
          case Err_nloads: fprintf(stderr,"Too many loads.\n"); break;
          case Err_nnetws: fprintf(stderr,"Too many networks and/or transmission lines.\n"); break;
       }
+      lastCard[0]=s[0];
+      lastCard[1]=s[1];
       fgets(s,100,f);
    }
    extr = extr_str;
