@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2002, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -749,16 +749,30 @@ int read_nec_output(FILE *f)          /* tries to read NEC output data from f; r
       EXPAND_IF_NECESSARY(numneco,maxfreqs,neco)
    
       /* search for the frequency and read it */
-      do fgets(s,200,f);  while (!feof(f) && !strstr(s,"FREQUENCY="));
+      do fgets(s,200,f);  while (!feof(f) && !strstr(s,"FREQUENCY=") && !strstr(s,"FREQUENCY : "));
       if (feof(f)) break;
       p = strchr(s,'=');
+      if (!p) p = strchr(s,':');
       freq = atof(p+1);
 
-      /* find the right place in the neco array (data is sorted by frequency) */
+      /* find the right place in memory, and prepare it if needed */
       if (numneco==0 || freq>neco[numneco-1].f) {
          ne=neco+numneco;
          numneco++;
+         ne->f=0;
+      } else {
+         for (i=0, ne=neco; i<numneco; i++, ne++)
+            if (ne->f>=freq) {
+               if (ne->f==freq) break;
+               memmove(ne+1,ne,(neco+numneco-ne)*sizeof(NECoutput));
+               numneco++;
+               if (new_rp_index>=i) new_rp_index++;
+               break;
+            }
+      }
+      if (ne->f!=freq) {
          ne->f = freq;
+         ne->rpgpovalid = 0;
          ne->rp = NULL;
          ne->cu = NULL;
          ne->nf = NULL;
@@ -768,25 +782,6 @@ int read_nec_output(FILE *f)          /* tries to read NEC output data from f; r
          ne->d[neco_maxgain_vert]=-DBL_MAX;
          ne->d[neco_maxgain_lhcp]=-DBL_MAX;
          ne->d[neco_maxgain_rhcp]=-DBL_MAX;
-      } else {
-         for (i=0, ne=neco; i<numneco; i++, ne++)
-            if (ne->f>=freq) {
-               if (ne->f==freq) break;
-               memmove(ne+1,ne,(neco+numneco-ne)*sizeof(NECoutput));
-               numneco++;
-               if (new_rp_index>=i) new_rp_index++;
-               ne->f = freq;
-               ne->rp = NULL;
-               ne->cu = NULL;
-               ne->nf = NULL;
-               ne->maxe = ne->maxh = 0;
-               ne->d[neco_maxgain]=-9999;
-               ne->d[neco_maxgain_hor]=-9999;
-               ne->d[neco_maxgain_vert]=-9999;
-               ne->d[neco_maxgain_lhcp]=-9999;
-               ne->d[neco_maxgain_rhcp]=-9999;
-               break;
-            }
       }
 
       /* find and read the input impedance, and calculate the SWR */
