@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2003, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -12,7 +12,7 @@
 #include "config.h"        /* file defining things like default colours etc. */
 
 
-#define VERSION "1.34"
+#define VERSION "1.35"
 
 
 typedef struct {     /* structure to describe a point in 3D space */ 
@@ -347,9 +347,9 @@ void draw_all(int ie);                      /* draw antenna structure and/or gai
 
 void calcproj(void);                        /* calculate the projection matrix etc. */
 
-int write_png(int which,char *filename);    /* write window 1 or 2 to an PNG file; return !=0 in case of error */
+int write_png(int which,const char *filename);    /* write window 1 or 2 to an PNG file; return !=0 in case of error */
 
-int write_postscript(char *filename,void (*drawfn)(int),int xsize, int ysize);
+int write_postscript(const char *filename,void (*drawfn)(int),int xsize, int ysize);
                                             /* write postscript to file; return !=0 in case of error */
 
 void draw_all2(int dummy);                  /* draw plot(s) vs. frequency */
