@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2003, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -14,7 +14,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 
 #ifdef HAVE_LIBPNG
@@ -236,7 +235,7 @@ int query_pixmap(GdkPixmap *w,int x, int y)
 /* -------------------- export a widget as a PNG file ---------------------------------------- */
 
 #ifdef HAVE_LIBPNG
-int write_png(int which,char *filename)
+int write_png(int which,const char *filename)
 {
    GdkImage *image;
    GdkWindow *w;
@@ -258,10 +257,10 @@ int write_png(int which,char *filename)
    }
    gdk_window_get_size(w,&width,&height);
 
-   f=fopen(filename,"w");
+   f=fopen(filename,"wb");
    if (!f) return 1;
 
-   image = gdk_image_get(gbackg, 0, 0, width, height);
+   image = gdk_image_get(w, 0, 0, width, height);
    if (!image) {
       fclose(f);
       return 1;
@@ -397,7 +396,7 @@ gint buttonrelease_event(GtkWidget *w,GdkEventButton *ev,gpointer dummy)
       return TRUE;
    }
 
-   if (ev->button==Button1) {
+   if (ev->button==1) {
       zoom*=1.4142;
       trx-=(double)(ev->x-winsizex/2)/zoom/winsize;
       try-=(double)(ev->y-winsizey/2)/zoom/winsize;
@@ -407,7 +406,7 @@ gint buttonrelease_event(GtkWidget *w,GdkEventButton *ev,gpointer dummy)
       if (plot2_vgain && redraw2==0) redraw2=2;
    }
 
-   if (ev->button==Button2) { 
+   if (ev->button==2) { 
       zoom=ini_zoom;
       phi=ini_phi;
       theta=ini_theta;
@@ -421,7 +420,7 @@ gint buttonrelease_event(GtkWidget *w,GdkEventButton *ev,gpointer dummy)
       if (plot2_vgain && redraw2==0) redraw2=2;
    }
 
-   if (ev->button==Button3) {
+   if (ev->button==3) {
       zoom/=1.4142;
       calcproj();
       redraw=1;
@@ -468,7 +467,7 @@ gint motion_event(GtkWidget *w,GdkEventMotion *ev,gpointer dummy)
    dx=pos_x-lastx;
    dy=pos_y-lasty;
 
-   if (ev->state & Button1Mask) {
+   if (ev->state & GDK_BUTTON1_MASK) {
       /* drag with button1: rotate */
       theta-=180.*(double)dy/(double)winsizey;
       if (theta<0) theta=0;
@@ -477,14 +476,14 @@ gint motion_event(GtkWidget *w,GdkEventMotion *ev,gpointer dummy)
       scaleplot=0;
       calc_vgain();
       if (plot2_vgain && redraw2==0) redraw2=2;
-   } else if (ev->state & Button2Mask) {
+   } else if (ev->state & GDK_BUTTON2_MASK) {
       /* drag with button2: zoom in/out */
       double z;
       z=5*(double)(dx-dy)/winsize;
       zoom*=z+1;
       trx-=(double)(origx-winsizex/2)/winsize*z/zoom;
       try-=(double)(origy-winsizey/2)/winsize*z/zoom;
-   } else if (ev->state&Button3Mask) {
+   } else if (ev->state & GDK_BUTTON3_MASK) {
       /* drag with button3: translate */
       trx+=(double)(dx)/zoom/winsize;
       try+=(double)(dy)/zoom/winsize;
@@ -826,7 +825,7 @@ void cmd_animfreq(GtkAdjustment *adj)
 
 void cmd_export_eps_ok(GtkWidget *w, GtkFileSelection *fs)
 {
-   char *s;
+   const char *s;
    s=gtk_file_selection_get_filename(fs);
    if (write_postscript(s,draw_all,winsizex,winsizey)) fprintf(stderr,"Error writing postscript\n");
    gtk_widget_destroy(GTK_WIDGET(fs));
@@ -835,7 +834,7 @@ void cmd_export_eps_ok(GtkWidget *w, GtkFileSelection *fs)
 #ifdef HAVE_LIBPNG
 void cmd_export_png_ok(GtkWidget *w, GtkFileSelection *fs)
 {
-   char *s;
+   const char *s;
    s=gtk_file_selection_get_filename(fs);
    if (write_png(1,s)) fprintf(stderr,"Error writing PNG\n");
    gtk_widget_destroy(GTK_WIDGET(fs));
@@ -843,15 +842,16 @@ void cmd_export_png_ok(GtkWidget *w, GtkFileSelection *fs)
 #endif
 
 
-void do_animation(void)
+int do_animation(void)
 {
-   if (animfreq==0) return;
-   if (animbusy) return;
-   if (structplot!=SPanim && gainplot!=GPnearfield) return;
+   if (animfreq==0) return 1;
+   if (animbusy) return 1;
+   if (structplot!=SPanim && gainplot!=GPnearfield) return 1;
    animphase+=0.002*anim_update_interval*M_PI*animfreq;
    if (animphase>2*M_PI) animphase-=2*M_PI;
    redraw=1;
    animbusy=1;
+   return 1;
 }
 
 
@@ -955,7 +955,7 @@ gint keypress_event2(GtkWidget *w,GdkEventKey *ev,gpointer dummy)
 
 void cmd_export2_eps_ok(GtkWidget *w, GtkFileSelection *fs)
 {
-   char *s;
+   const char *s;
    s=gtk_file_selection_get_filename(fs);
    if (write_postscript(s,draw_all2,win2sizex,win2sizey)) fprintf(stderr,"Error writing postscript\n");
    gtk_widget_destroy(GTK_WIDGET(fs));
@@ -964,7 +964,7 @@ void cmd_export2_eps_ok(GtkWidget *w, GtkFileSelection *fs)
 #ifdef HAVE_LIBPNG
 void cmd_export2_png_ok(GtkWidget *w, GtkFileSelection *fs)
 {
-   char *s;
+   const char *s;
    s=gtk_file_selection_get_filename(fs);
    if (write_png(2,s)) fprintf(stderr,"Error writing PNG\n");
    gtk_widget_destroy(GTK_WIDGET(fs));
@@ -1012,7 +1012,7 @@ void cmd_export_png(GtkWidget *ww,void(*f)())
 void cmd_setZ0(GtkEntry *w)
 {
    double r;
-   char *q,*p;
+   const char *q,*p;
    char s[20];
 
    q=gtk_entry_get_text(w);
@@ -1378,7 +1378,7 @@ void maininitX(int really)
 
       gtk_widget_grab_focus(gdraw1);
 
-      gtk_accel_group_attach(acc, GTK_OBJECT(win1));
+      gtk_window_add_accel_group(GTK_WINDOW(win1), acc);
 
       ggc = gdk_gc_new(w->window);
 
@@ -1478,7 +1478,7 @@ void maininitX(int really)
 
       gtk_widget_grab_focus(gdraw2);
 
-      gtk_accel_group_attach(acc, GTK_OBJECT(win2));
+      gtk_window_add_accel_group(GTK_WINDOW(win2), acc);
 
       ggc2 = gdk_gc_new(w->window);
 
@@ -1525,7 +1525,7 @@ void maininitX(int really)
    if (gdraw1==NULL) gdraw1=gdraw2;
    else if (gdraw2==NULL) gdraw2=gdraw1;
 
-   gtk_timeout_add( anim_update_interval, (GtkFunction) do_animation, NULL);
+   g_timeout_add( anim_update_interval, (GtkFunction) do_animation, NULL);
 }
 
 
